import { Session } from "@sajari/sdk-js";
import { CallbackFn, UnlistenFn } from "../listener";
export declare class Tracking {
    clientTracking: Session | null;
    private listeners;
    constructor();
    /**
     * Register a listener for a specific event.
     * @param event Event to listen for
     * @param callback Callback to run when the event happens.
     * @return The unregister function to remove the callback from the listener.
     */
    listen(event: string, callback: CallbackFn): UnlistenFn;
    /**
     * Emits a tracking reset event to the tracking reset event listener.
     * @private
     */
    _emitTrackingReset(values: {
        [k: string]: string;
    }): void;
    /**
     * Reset the tracking.
     * @param values Key-value pair parameters to use in the pipeline.
     */
    reset(values?: {
        [k: string]: string;
    }): void;
    /**
     * Tracking returns the tracking data to be attached to the pipeline request.
     * @param values Key-value pair parameters to use in the pipeline.
     * @return Tracking values to be used in the search request.
     */
    next(values: {
        [k: string]: string;
    }): void;
}
